@@ -105,7 +105,7 @@ class BarProvider:
         if self.is_end:
             self.change_state = 4
             return
-        result = self.__move_to(new_bar.begin_time, False)
+        result = self.__move_to(new_bar.begin_time, new_bar.end_time)
         ir = result[0]
         index = result[1]
         if ir == -1:
@@ -184,7 +184,7 @@ class BarProvider:
             self.change_state = 4
             return
 
-        result = self.__move_to(tick.date_time)  # 自动判断是否切换下个区间
+        result = self.__move_to(tick.date_time, tick.date_time)  # 自动判断是否切换下个区间
         ir = result[0]
         index = result[1]
         if ir == -1:
@@ -270,12 +270,12 @@ class BarProvider:
 
         self.change_state = 3
 
-    def __move_to(self, now, is_tick=True):
+    def __move_to(self, begin_time, end_time):
         index = self.__pos_time
 
         # region -1 无效
         current_date_time_slice = self.__lst_date_time_slices[self.__pos_time]
-        if now < current_date_time_slice.begin_time:
+        if begin_time < current_date_time_slice.begin_time:
             return -1, index
         # endregion
 
@@ -284,7 +284,7 @@ class BarProvider:
             date_time_slice = self.__lst_date_time_slices[index]
             next_date_time_slice = self.__lst_date_time_slices[index + 1]
 
-            ir = self.__is_current_date_time_slice(date_time_slice, next_date_time_slice, now, is_tick)
+            ir = self.__is_current_date_time_slice(date_time_slice, next_date_time_slice, begin_time, end_time)
             if ir == 0:
                 return 0, index
             # 处理盘中休息的异常数据(一般不会出现这种情况)
@@ -294,7 +294,7 @@ class BarProvider:
             index += 1
 
         # 收盘以后的Tick处理
-        bmy = self.__is_current_date_time_slice(self.__lst_date_time_slices[index], None, now, is_tick)
+        bmy = self.__is_current_date_time_slice(self.__lst_date_time_slices[index], None, begin_time, end_time)
         if bmy == 0:
             return 0, index
 
@@ -305,24 +305,20 @@ class BarProvider:
         return 1, index
 
     @staticmethod
-    def __is_current_date_time_slice(current_date_time_slice, next_date_time_slice, date_time, is_tick=True):
+    def __is_current_date_time_slice(current_date_time_slice, next_date_time_slice, begin_time, end_time):
         if next_date_time_slice is not None:
             if current_date_time_slice.end_time < next_date_time_slice.begin_time:
-                if (date_time > current_date_time_slice.end_time) & (date_time < next_date_time_slice.begin_time):
-                    ta = date_time - current_date_time_slice.end_time
-                    tb = next_date_time_slice.begin_time - date_time
+                if (begin_time > current_date_time_slice.end_time) & (begin_time < next_date_time_slice.begin_time):
+                    ta = begin_time - current_date_time_slice.end_time
+                    tb = next_date_time_slice.begin_time - begin_time
                     if tb.total_seconds() < ta.total_seconds():
                         return 2
                     return 0
 
-            if (current_date_time_slice.begin_time <= date_time) & (date_time < next_date_time_slice.begin_time):
+            if (current_date_time_slice.begin_time <= begin_time) & (end_time < next_date_time_slice.begin_time):
                 return 0
         else:
             # 收盘5秒内的tick都计算
-            if is_tick:
-                if (current_date_time_slice.begin_time <= date_time) & (date_time < (current_date_time_slice.end_time + datetime.timedelta(seconds=1000))):
-                    return 0
-            else:
-                if (current_date_time_slice.begin_time <= date_time) & (date_time < (current_date_time_slice.end_time + datetime.timedelta(seconds=0))):
-                    return 0
+            if (current_date_time_slice.begin_time <= begin_time) & (end_time < (current_date_time_slice.end_time + datetime.timedelta(seconds=59))):
+                return 0
         return 1
