@@ -56,28 +56,28 @@ end_time = datetime.datetime(trading_day.year, trading_day.month, trading_day.da
 #     print("["+instrument_id+"]"+str(index)+":"+bar.to_string()+','+str(bar.pre_close))
 #     index += 1
 
-begin_trading_date = datetime.datetime(2017, 7, 4, 13, 54, 0)
-end_trading_date = datetime.datetime(2017, 7, 5, 10, 9, 0)
-instrument_id = "rb9999"
-interval = 5
-bar_type = EnumBarType.minute
-bar_series = qi_data_controller.load_bar_series_by_date_time(EnumMarket.期货, instrument_id, interval, bar_type, begin_trading_date, end_trading_date)
-index = 1
-for bar in bar_series:
-    print("["+instrument_id+"]"+str(index)+":"+bar.to_string()+','+str(bar.pre_close))
-    index += 1
-
-# length = 20
-# end_trading_date = datetime.datetime(2019, 5, 7, 0, 0, 0)
-# instrument_id = "ag9999"
+# begin_trading_date = datetime.datetime(2017, 7, 4, 13, 54, 0)
+# end_trading_date = datetime.datetime(2017, 7, 5, 10, 9, 0)
+# instrument_id = "rb9999"
 # interval = 5
 # bar_type = EnumBarType.minute
-# bar_series = qi_data_controller.load_bar_series_by_length(EnumMarket.期货, instrument_id, interval, bar_type, length, end_trading_date)
+# bar_series = qi_data_controller.load_bar_series_by_date_time(EnumMarket.期货, instrument_id, interval, bar_type, begin_trading_date, end_trading_date)
 # index = 1
 # for bar in bar_series:
-#     print("["+instrument_id+"]"+str(index)+":"+bar.to_string())
+#     print("["+instrument_id+"]"+str(index)+":"+bar.to_string()+','+str(bar.pre_close))
 #     index += 1
 
+length = 20
+end_trading_date = datetime.datetime(2019, 5, 7)
+instrument_id = "ag9999"
+interval = 1
+bar_type = EnumBarType.day
+bar_series = qi_data_controller.load_bar_series_by_length(EnumMarket.期货, instrument_id, interval, bar_type, length, end_trading_date)
+index = 1
+for bar in bar_series:
+    print("["+instrument_id+"]"+str(index)+":"+bar.to_string())
+    index += 1
+
 # lst_a = []
 # for bar in bar_series:
 #     lst_a.append([bar.trading_date, bar.begin_time, bar.end_time, bar.open, bar.high, bar.low, bar.close, bar.pre_close, bar.volume])
